{% extends 'report_html_stock/reports/restocking_base.html' %}

{% block title %}
  Restocking List
{% endblock %}

{% block header scoped %}
  <div class="col-xs-6">
    <div>
      {% block header_logo %}
      {% endblock %}
    </div>
  </div>
  <div class="col-xs-6">
    <div class="row">
      <div class="col-xs-12">
        <span class="h3">Restocking List</span>
      </div>
    </div>
    <div class="row" style="padding-top:20px;">
      <div class="col-xs-5">
        <strong>Code:</strong>
      </div>
      <div class="col-xs-7">
        {{ shipment.code }}
      </div>
    </div>
    <div class="row">
      <div class="col-xs-5">
        <strong>Refrence:</strong>
      </div>
      <div class="col-xs-7">
        {{ shipment.origins or '' }}{{ ', ' if (shipment.origins and shipment.reference) else '' }}{{ shipment.reference or '' }}
      </div>
    </div>
    <div class="row">
      <div class="col-xs-5">
        <strong>Customer:</strong>
      </div>
      <div class="col-xs-7">
        {{ shipment.customer.rec_name }}
      </div>
    </div>
    <div class="row">
      <div class="col-xs-5">
        <strong>Planned Date:</strong>
      </div>
      <div class="col-xs-7">
        {{ shipment.planned_date and shipment.planned_date|dateformat }}
      </div>
    </div>
    <div class="row">
      <div class="col-xs-5">
        <strong>Warehouse:</strong>
      </div>
      <div class="col-xs-7">
        {{ shipment.warehouse.rec_name }}
      </div>
    </div>
  </div>
{% endblock %} 
